@@ -9,6 +9,7 @@ import pytest
 
 from configupdater import (
     AlreadyAttachedError,
+    AssignMultilineValueError,
     Comment,
     ConfigUpdater,
     DuplicateOptionError,
@@ -1333,3 +1334,161 @@ def test_comments_in_multiline_values():
     parser.read_string(dedent(error_case_if_no_value))
     updater.read_string(dedent(error_case_if_no_value))
     assert str(updater) == dedent(error_case_if_no_value)
+
+
+def test_modify_multiline_value():
+    ml_value = """\
+    [metadata]
+    classifiers =
+        Development Status :: 3 - Alpha
+        #Development Status :: 4 - Beta
+        #Development Status :: 5 - Production/Stable
+        Programming Language :: Python :: 3 :: Only
+        Programming Language :: Python :: 3
+        Programming Language :: Python :: Implementation :: CPython
+        Programming Language :: Python :: Implementation :: PyPy
+        License :: OSI Approved :: MIT License
+    """
+    ml_value = dedent(ml_value)
+    updater = ConfigUpdater()
+    updater.read_string(ml_value)
+
+    with pytest.raises(AssignMultilineValueError):
+        updater["metadata"]["classifiers"].value += "License :: OSI Approved :: BSD"
+
+    new_classifiers = updater["metadata"]["classifiers"].value.strip().split("\n")
+    new_classifiers += ["Topic :: Utilities"]
+    updater["metadata"]["classifiers"].set_values(new_classifiers)
+    ml_value += "    Topic :: Utilities\n"
+    assert str(updater) == ml_value
+
+    updater["metadata"]["classifiers"].value = "new_value"
+    updater["metadata"]["classifiers"].value += "_and_more"
+    expected = """\
+    [metadata]
+    classifiers = new_value_and_more
+    """
+    assert str(updater) == dedent(expected)
+
+
+def test_append_to_multi_line_value():
+    cfg = """\
+    [metadata]
+    classifiers =
+        Development Status :: 3 - Alpha
+        #Development Status :: 4 - Beta
+        #Development Status :: 5 - Production/Stable
+        Programming Language :: Python :: 3 :: Only
+        Programming Language :: Python :: 3
+        Programming Language :: Python :: Implementation :: CPython
+        Programming Language :: Python :: Implementation :: PyPy
+        License :: OSI Approved :: MIT License
+    """
+    cfg = dedent(cfg)
+    updater = ConfigUpdater()
+    updater.read_string(cfg)
+    updater["metadata"]["classifiers"].append("Topic :: Utilities")
+    cfg += "    Topic :: Utilities\n"
+    assert str(updater) == cfg
+
+
+def test_append_to_comma_separated_value():
+    cfg = """\
+    [metadata]
+    classifiers = terminal, developers
+    """
+    cfg = dedent(cfg)
+    updater = ConfigUpdater()
+    updater.read_string(cfg)
+    option = updater["metadata"]["classifiers"]
+    option.append("gui", separator=", ")
+
+    cfg_out = """\
+    [metadata]
+    classifiers = terminal, developers, gui
+    """
+    cfg_out = dedent(cfg_out)
+    assert str(updater) == cfg_out
+
+
+def test_append_to_no_multi_line_value():
+    cfg_in = """\
+    [main]
+    key = value1
+    """
+    cfg_out = """\
+    [main]
+    key =
+        value1
+        new_value
+    """
+    cfg_in, cfg_out = dedent(cfg_in), dedent(cfg_out)
+    updater = ConfigUpdater()
+    updater.read_string(cfg_in)
+    updater["main"]["key"].append("new_value")
+
+    target = ConfigUpdater()
+    target.read_string(cfg_out)
+    assert str(updater) == str(target)
+
+    updater["main"]["key"].append("new_value2")
+    cfg_out += "    new_value2\n"
+    assert str(updater) == cfg_out
+
+
+def test_as_list_multi_line():
+    cfg = """\
+    [metadata]
+    no_value
+    single_value = 1
+    classifiers =
+        Development Status :: 3 - Alpha
+        #Development Status :: 4 - Beta
+    """
+    cfg = dedent(cfg)
+    updater = ConfigUpdater(allow_no_value=True)
+    updater.read_string(cfg)
+
+    meta = updater["metadata"]
+    assert meta["no_value"].as_list() == []
+    assert meta["single_value"].as_list() == ["1"]
+    assert meta["classifiers"].as_list() == [
+        "Development Status :: 3 - Alpha",
+        "#Development Status :: 4 - Beta",
+    ]
+
+
+def test_as_list_comma_separated():
+    cfg = """\
+    [metadata]
+    classifiers = terminal, developers
+    """
+    cfg = dedent(cfg)
+    updater = ConfigUpdater()
+    updater.read_string(cfg)
+    option = updater["metadata"]["classifiers"]
+    assert option.as_list(",") == ["terminal", "developers"]
+
+
+def test_indented_section():
+    cfg = """\
+    [section0]
+
+        [section1]
+            key = value
+    """
+
+    updater = ConfigUpdater()
+    updater.read_string(dedent(cfg))
+
+    assert str(updater) == dedent(cfg)
+
+
+def test_section_without_end_of_line():
+    cfg = """\
+    [section]"""
+
+    updater = ConfigUpdater()
+    updater.read_string(dedent(cfg))
+
+    assert str(updater) == dedent(cfg)
